tslumen.plot package
====================

.. automodule:: tslumen.plot
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::
   :maxdepth: 3

   tslumen.plot.static
   tslumen.plot.interactive
